# pytonik

[![Build Status](https://img.shields.io/pypi/v/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Downloads](https://img.shields.io/pypi/dm/pytonik)](https://pypi.python.org/pypi/pytonik/)
[![Wheel](https://img.shields.io/pypi/wheel/pytonik.svg)](https://pypi.python.org/pypi/pytonik)
[![Python Version](https://img.shields.io/pypi/pyversions/pytonik)](https://pypi.python.org/pypi/pytonik)
[![License](https://img.shields.io/pypi/l/pytonik)](https://pypi.python.org/pypi/pytonik)

Pytonik is a python framework built to enhance web development fast and easy, also help web developers to build more apps with less codes. it uses expressive architectural pattern, structured on model view controller MVC  and bundles of component to reuse while deploying the framework.

[![Made with python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://pypi.python.org/pypi/pytonik)



## How to install

We recommend you to install pytonik package using Terminal or Command Line Window

```
$ pip install pytonik==1.9.7b1
```


Terminal tool to start project folder structure
 
```
pytonik-start

```
Terminal tool to start server
 
```
pytonik-server

```

## Table of Content

* [Getting Started](https://pytonik.readthedocs.io/en/latest/getting-started.html)
* [Configuration](hhttps://pytonik.readthedocs.io/en/latest/configuration.html)
* [Dependency](https://pytonik.readthedocs.io/en/latest/dependency.html)
* [File Structure](https://pytonik.readthedocs.io/en/latest/filestructure.html)
* [Environment File](https://pytonik.readthedocs.io/en/latest/env.html)
* [Template Engine](https://pytonik.readthedocs.io/en/latest/temp.html)
* [SMTP](https://pytonik.readthedocs.io/en/latest/smtp.html)
* [Request](https://pytonik.readthedocs.io/en/latest/request.html)
* [Session](https://pytonik.readthedocs.io/en/latest/session.html)
* [File](https://pytonik.readthedocs.io/en/latest/file.html)
* [Functions](https://pytonik.readthedocs.io/en/latest/func.html)
* [Schema](https://pytonik.readthedocs.io/en/latest/schema.html)
* [Advance](https://pytonik.readthedocs.io/en/latest/advance.html)
       

## Contact

**Name:**  Pytonik MVC

**Email:** dev@pytonik.com
